Returns the function environment as list. Raises an error when called outside a function. By default, objects specified as arguments are removed from the environment.
Usage
function_locals(without = c(), strip_function_args = TRUE)Returns the function environment as list. Raises an error when called outside a function. By default, objects specified as arguments are removed from the environment.
function_locals(without = c(), strip_function_args = TRUE)